@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::PluginBundle::NGLENN;
 # ABSTRACT: Dist::Zilla plugin configuration for me
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # Dependencies
 use Moose 0.99;
@@ -431,7 +431,7 @@ sub configure {
                         : (
                             commit_msg        => "After release: bump \$VERSION and timestamp Changes",
                             allow_dirty       => [qw/Changes Makefile.PL/],
-                            allow_dirty_match => '^lib',
+                            allow_dirty_match => '^lib|^bin',
                         )
                     }
                 ],
@@ -469,7 +469,7 @@ Dist::Zilla::PluginBundle::NGLENN - Dist::Zilla plugin configuration for me
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
